@@ -18,7 +18,7 @@ class InlineJavaProtocol {
 
 	private final String encoding = "UTF-8" ;
 
-	static private Map member_cache = Collections.synchronizedMap(new HashMap()) ;
+	static private Map<String, Member> member_cache = Collections.synchronizedMap(new HashMap<>()) ;
 	static private final String report_version = "V2" ;
 
 	InlineJavaProtocol(InlineJavaServer _ijs, String _cmd) {
@@ -106,7 +106,7 @@ class InlineJavaProtocol {
 
 		StringTokenizer st3 = new StringTokenizer(Decode(st2.nextToken()), " ") ;
 
-		ArrayList class_list = new ArrayList() ;
+		ArrayList<String> class_list = new ArrayList<>() ;
 		while (st3.hasMoreTokens()){
 			String c = st3.nextToken() ;
 			class_list.add(class_list.size(), c) ;
@@ -192,12 +192,12 @@ class InlineJavaProtocol {
 		String is_it_a = st.nextToken() ;
 		Class d = ijc.ValidateClass(is_it_a) ;
 
-		SetResponse(new Integer(ijc.DoesExtend(c, d))) ;
+		SetResponse(Integer.valueOf(ijc.DoesExtend(c, d))) ;
 	}
 
 
 	void ObjectCount(StringTokenizer st) throws InlineJavaException {
-		SetResponse(new Integer(ijs.ObjectCount())) ;
+		SetResponse(Integer.valueOf(ijs.ObjectCount())) ;
 	}
 
 
@@ -209,7 +209,7 @@ class InlineJavaProtocol {
 		Class c = ijc.ValidateClass(class_name) ;
 
 		if (! ijc.ClassIsArray(c)){
-			ArrayList f = ValidateMethod(true, c, class_name, st) ;
+			ArrayList<Object> f = ValidateMethod(true, c, class_name, st) ;
 			Object p[] = (Object [])f.get(1) ;
 			Class clist[] = (Class [])f.get(2) ;
 
@@ -271,10 +271,10 @@ class InlineJavaProtocol {
 
 		if ((ijc.ClassIsArray(c))&&(method.equals("getLength"))){
 			int length = Array.getLength(o) ;
-			SetResponse(new Integer(length)) ;
+			SetResponse(Integer.valueOf(length)) ;
 		}
 		else{
-			ArrayList f = ValidateMethod(false, c, method, st) ;
+			ArrayList<Object> f = ValidateMethod(false, c, method, st) ;
 			Method m = (Method)f.get(0) ;
 			String name = m.getName() ;	
 			Object p[] = (Object [])f.get(1) ;
@@ -374,10 +374,10 @@ class InlineJavaProtocol {
 			ret = InlineJavaHandle.makeBuffered(o) ;
 			if (ret != o){
 				int buf_id = ijs.PutObject(ret) ;
-				ret = new Integer(buf_id) ;
+				ret = Integer.valueOf(buf_id) ;
 			}
 			else {
-				ret = new Integer(id) ;
+				ret = Integer.valueOf(id) ;
 			}
 		}
 		catch (java.io.IOException e){
@@ -412,7 +412,7 @@ class InlineJavaProtocol {
 		Object ret = null ;
 		try {
 			int len = InlineJavaHandle.write(o, arg.toString()) ;
-			ret = new Integer(len) ;
+			ret = Integer.valueOf(len) ;
 		}
 		catch (java.io.IOException e){
 			ret = new InlineJavaThrown(e) ;
@@ -475,7 +475,7 @@ class InlineJavaProtocol {
 			}
 		}
 		else{
-			ArrayList fl = ValidateMember(c, member, st) ;
+			ArrayList<Object> fl = ValidateMember(c, member, st) ;
 			Field f = (Field)fl.get(0) ;
 			String name = f.getName() ;
 			Object p = (Object)fl.get(1) ;
@@ -519,7 +519,7 @@ class InlineJavaProtocol {
 			SetResponse(ret, AutoCast(ret, eclass)) ;
 		}
 		else{
-			ArrayList fl = ValidateMember(c, member, st) ;
+			ArrayList<Object> fl = ValidateMember(c, member, st) ;
 
 			Field f = (Field)fl.get(0) ;
 			String name = f.getName() ;
@@ -588,20 +588,20 @@ class InlineJavaProtocol {
 	/*
 		Makes sure a method exists
 	*/
-	ArrayList ValidateMethod(boolean constructor, Class c, String name, StringTokenizer st) throws InlineJavaException {
-		ArrayList ret = new ArrayList() ;
+	ArrayList<Object> ValidateMethod(boolean constructor, Class c, String name, StringTokenizer st) throws InlineJavaException {
+		ArrayList<Object> ret = new ArrayList<>() ;
 
 		// Extract signature
 		String signature = st.nextToken() ;
 
 		// Extract the arguments
-		ArrayList args = new ArrayList() ;
+		ArrayList<String> args = new ArrayList<>() ;
 		while (st.hasMoreTokens()){
 			args.add(args.size(), st.nextToken()) ;
 		}
 
 		String key = c.getName() + "." + name + signature ;
-		ArrayList ml = new ArrayList() ;
+		ArrayList<Member> ml = new ArrayList<>() ;
 		Class params[] = null ;
 
 		Member cached = (Member)member_cache.get(key) ;
@@ -686,8 +686,8 @@ class InlineJavaProtocol {
 	/*
 		Makes sure a member exists
 	*/
-	ArrayList ValidateMember(Class c, String name, StringTokenizer st) throws InlineJavaException {
-		ArrayList ret = new ArrayList() ;
+	ArrayList<Object> ValidateMember(Class c, String name, StringTokenizer st) throws InlineJavaException {
+		ArrayList<Object> ret = new ArrayList<>() ;
 
 		// Extract member type
 		String type = st.nextToken() ;
@@ -696,7 +696,7 @@ class InlineJavaProtocol {
 		String arg = st.nextToken() ;
 
 		String key = type + " " + c.getName() + "." + name ;
-		ArrayList fl = new ArrayList() ;
+		ArrayList<Member> fl = new ArrayList<>() ;
 		Class param = null ;
 
 		Member cached = (Member)member_cache.get(key) ;
